@@ -50,12 +50,10 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KHelpMenu>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KToolBar>
-
 #include <KSharedConfig>
+#include <KToolBar>
 
 #include "libkwave/ClipBoard.h"
 #include "libkwave/CodecManager.h"
@@ -105,22 +103,22 @@ Kwave::TopWidget::TopWidget(Kwave::App &app)
     :KMainWindow(),
      m_application(app),
      m_context_map(),
-     m_toolbar_record_playback(0),
-     m_toolbar_zoom(0),
-     m_menu_manager(0),
-     m_mdi_area(0),
-     m_action_save(0),
-     m_action_save_as(0),
-     m_action_close(0),
-     m_action_undo(0),
-     m_action_redo(0),
-     m_action_cut(0),
-     m_action_copy(0),
-     m_action_erase(0),
-     m_action_delete(0),
-     m_lbl_status_size(0),
-     m_lbl_status_mode(0),
-     m_lbl_status_cursor(0)
+     m_toolbar_record_playback(Q_NULLPTR),
+     m_toolbar_zoom(Q_NULLPTR),
+     m_menu_manager(Q_NULLPTR),
+     m_mdi_area(Q_NULLPTR),
+     m_action_save(Q_NULLPTR),
+     m_action_save_as(Q_NULLPTR),
+     m_action_close(Q_NULLPTR),
+     m_action_undo(Q_NULLPTR),
+     m_action_redo(Q_NULLPTR),
+     m_action_cut(Q_NULLPTR),
+     m_action_copy(Q_NULLPTR),
+     m_action_erase(Q_NULLPTR),
+     m_action_delete(Q_NULLPTR),
+     m_lbl_status_size(Q_NULLPTR),
+     m_lbl_status_mode(Q_NULLPTR),
+     m_lbl_status_cursor(Q_NULLPTR)
 {
     // status bar items
     QStatusBar *status_bar = statusBar();
@@ -205,20 +203,20 @@ void Kwave::TopWidget::connectContext(Kwave::FileContext *context)
 Kwave::FileContext *Kwave::TopWidget::newFileContext()
 {
     Q_ASSERT(m_toolbar_zoom);
-    if (!m_toolbar_zoom) return 0;
+    if (!m_toolbar_zoom) return Q_NULLPTR;
 
     Kwave::FileContext *context =
 	new(std::nothrow) Kwave::FileContext(m_application);
-    if (!context) return 0;
+    if (!context) return Q_NULLPTR;
     if (!context->init(this)) {
 	delete context;
-	return 0;
+        return Q_NULLPTR;
     }
 
     // if we are in SDI mode, there is a context but no MDI sub window
     // and in MDI/TAB mode we use this special entry for a context that
     // has just been created but has no sub window yet
-    m_context_map[0] = context;
+    m_context_map[Q_NULLPTR] = context;
 
     // do all signal/slot connections
     connectContext(context);
@@ -233,14 +231,14 @@ Kwave::FileContext *Kwave::TopWidget::newFileContext()
 //***************************************************************************
 Kwave::FileContext *Kwave::TopWidget::currentContext() const
 {
-    if (m_context_map.isEmpty()) return 0;
+    if (m_context_map.isEmpty()) return Q_NULLPTR;
 
-    if (m_context_map.contains(0)) {
+    if (m_context_map.contains(Q_NULLPTR)) {
 	// the "null" entry is special, it has precedence over all
 	// other entries. In SDI mode it is the only one ever and in
 	// MDI/TAB mode it is used for a context that has no sub
 	// window yet.
-	return m_context_map[0];
+        return m_context_map[Q_NULLPTR];
     }
 
     if (m_mdi_area) {
@@ -250,26 +248,24 @@ Kwave::FileContext *Kwave::TopWidget::currentContext() const
 	    qWarning("WARNING: unassociated MDI sub window %p?",
 	             static_cast<void *>(current_sub));
 	    QMapIterator<QMdiSubWindow*, Kwave::FileContext*> it(m_context_map);
-	    Kwave::FileContext *context = 0;
+            Kwave::FileContext *context = Q_NULLPTR;
 	    while (it.hasNext()) {
 		it.next();
 		context = it.value();
 	    }
-	    return (m_context_map.count() == 1) ? context : 0;
+	    return (m_context_map.count() == 1) ? context : Q_NULLPTR;
 	}
 	return m_context_map[current_sub];
     } else {
 	// SDI mode
 	Q_ASSERT(0 && "SDI mode but no context?");
-	return 0;
+        return Q_NULLPTR;
     }
 }
 
 //***************************************************************************
 bool Kwave::TopWidget::init()
 {
-    KIconLoader icon_loader;
-
     showInSplashSreen(i18n("Loading main menu..."));
     QMenuBar *menubar = menuBar();
     Q_ASSERT(menubar);
@@ -309,7 +305,7 @@ bool Kwave::TopWidget::init()
     Kwave::FileContext *context = newFileContext();
     if (!context) return false;
 
-    QWidget *central_widget = 0;
+    QWidget *central_widget = Q_NULLPTR;
     switch (m_application.guiType()) {
 	case Kwave::App::GUI_SDI:
 	    // create a main widget
@@ -351,27 +347,27 @@ bool Kwave::TopWidget::init()
     // --- file open and save ---
 
     toolbar_file->addAction(
-	icon_loader.loadIcon(_("document-new"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("document-new")),
 	i18n("Create a new empty file"),
 	this, SLOT(toolbarFileNew()));
 
     toolbar_file->addAction(
-	icon_loader.loadIcon(_("document-open"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("document-open")),
 	i18n("Open an existing file"),
 	this, SLOT(toolbarFileOpen()));
 
     m_action_save = toolbar_file->addAction(
-	icon_loader.loadIcon(_("document-save"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("document-save")),
 	i18n("Save the current file"),
 	this, SLOT(toolbarFileSave()));
 
     m_action_save_as = toolbar_file->addAction(
-	icon_loader.loadIcon(_("document-save-as"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("document-save-as")),
 	i18n("Save the current file under a different name or file format..."),
 	this, SLOT(toolbarFileSaveAs()));
 
     m_action_close = toolbar_file->addAction(
-	icon_loader.loadIcon(_("document-close"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("document-close")),
 	i18n("Close the current file"),
 	this, SLOT(toolbarFileClose()));
 
@@ -382,27 +378,27 @@ bool Kwave::TopWidget::init()
     if (!toolbar_edit) return false;
 
     m_action_undo = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-undo"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-undo")),
 	i18n("Undo"),
 	this, SLOT(toolbarEditUndo()));
 
     m_action_redo = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-redo"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-redo")),
 	i18n("Redo"),
 	this, SLOT(toolbarEditRedo()));
 
     m_action_cut = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-cut"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-cut")),
 	i18n("Cut"),
 	this, SLOT(toolbarEditCut()));
 
     m_action_copy = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-copy"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-copy")),
 	i18n("Copy"),
 	this, SLOT(toolbarEditCopy()));
 
     QAction *btPaste = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-paste"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-paste")),
 	i18n("Insert"),
 	this, SLOT(toolbarEditPaste()));
     btPaste->setEnabled(!Kwave::ClipBoard::instance().isEmpty());
@@ -410,12 +406,12 @@ bool Kwave::TopWidget::init()
             btPaste, SLOT(setEnabled(bool)));
 
     m_action_erase = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("draw-eraser"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("draw-eraser")),
 	i18n("Mute selection"),
 	this, SLOT(toolbarEditErase()));
 
     m_action_delete = toolbar_edit->addAction(
-	icon_loader.loadIcon(_("edit-delete"), KIconLoader::Toolbar),
+	QIcon::fromTheme(_("edit-delete")),
 	i18n("Delete selection"),
 	this, SLOT(toolbarEditDelete()));
 
@@ -487,13 +483,13 @@ Kwave::TopWidget::~TopWidget()
     closeAllSubWindows();
 
     delete m_toolbar_zoom;
-    m_toolbar_zoom = 0;
+    m_toolbar_zoom = Q_NULLPTR;
 
     delete m_toolbar_record_playback;
-    m_toolbar_record_playback = 0;
+    m_toolbar_record_playback = Q_NULLPTR;
 
     delete m_menu_manager;
-    m_menu_manager = 0;
+    m_menu_manager = Q_NULLPTR;
 
     while (!m_context_map.isEmpty()) {
 	Kwave::FileContext *context = m_context_map.values().last();
@@ -545,14 +541,14 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
 	    }
 
 	    // detach the main widget from the MDI sub window
-	    sub->setWidget(0);
+	    sub->setWidget(Q_NULLPTR);
 	    delete sub;
 	}
 
 	// detach the context from this parent widget
 	if (context) {
 	    context->disconnect();
-	    context->setParent(0);
+            context->setParent(Q_NULLPTR);
 	    if (context->isInUse())
 		list += context;    // in use -> keep
 	    else
@@ -561,13 +557,13 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
     }
 
     // get rid of the MDI area, it should be empty now
-    setCentralWidget(0);
+    setCentralWidget(Q_NULLPTR);
     if (m_mdi_area) {
 	delete m_mdi_area;
-	m_mdi_area = 0;
+        m_mdi_area = Q_NULLPTR;
     }
 
-    emit sigFileContextSwitched(0);
+    emit sigFileContextSwitched(Q_NULLPTR);
 
     return list;
 }
@@ -585,7 +581,8 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 	{
 	    context->createMainWidget(geometry().size() * 0.85);
 	}
-	m_context_map.remove(0); // prevent it from getting removed again
+	// prevent it from getting removed again
+	m_context_map.remove(Q_NULLPTR);
     }
 
     switch (m_application.guiType()) {
@@ -593,12 +590,12 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 	    // we may have an empty default context -> get rid of it
 	    Q_ASSERT(m_context_map.count() <= 1);
 	    if (!m_context_map.isEmpty()) {
-		Kwave::FileContext *ctx = m_context_map[0];
-		m_context_map.remove(0);
+                Kwave::FileContext *ctx = m_context_map[Q_NULLPTR];
+                m_context_map.remove(Q_NULLPTR);
 		if (ctx) ctx->release();
 	    }
 	    // take over the new context
-	    m_context_map[0] = context;
+	    m_context_map[Q_NULLPTR] = context;
 	    connectContext(context);
 	    context->setParent(this);
 
@@ -639,8 +636,8 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 		if (!sub) return;
 		sub->adjustSize();
 
-		if (m_context_map.contains(0))
-		    m_context_map.remove(0);
+                if (m_context_map.contains(Q_NULLPTR))
+                    m_context_map.remove(Q_NULLPTR);
 		m_context_map[sub] = context;
 
 		connect(context->mainWidget(), SIGNAL(destroyed(QObject*)),
@@ -689,7 +686,7 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 		sub->setHidden(false);
 		m_mdi_area->setActiveSubWindow(sub);
 	    } else {
-		m_context_map[0] = context; // set empty default context
+                m_context_map[Q_NULLPTR] = context; // set empty default context
 	    }
 
 	    break;
@@ -697,7 +694,7 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
     }
 
     // update the menu bar, toolbar etc.
-    emit sigFileContextSwitched(0);
+    emit sigFileContextSwitched(Q_NULLPTR);
     emit sigFileContextSwitched(context);
     updateMenu();
     updateToolbar();
@@ -920,7 +917,7 @@ bool Kwave::TopWidget::closeAllSubWindows()
 	    it.remove();
 	    if (m_context_map.isEmpty()) {
 		// keep the default context, without a window
-		m_context_map[0] = context;
+                m_context_map[Q_NULLPTR] = context;
 		break;
 	    }
 	}
@@ -938,7 +935,7 @@ int Kwave::TopWidget::newWindow(Kwave::FileContext *&context, const QUrl &url)
 	    // -> open a new toplevel window
 	    //    (except for processing commands per kwave: URL
 	    Kwave::SignalManager *signal_manager = (context) ?
-		context->signalManager() : 0;
+		context->signalManager() : Q_NULLPTR;
 	    if ( signal_manager && !signal_manager->isEmpty() &&
 		(url.scheme().toLower() != Kwave::urlScheme()) )
 		return m_application.newWindow(url);
@@ -956,10 +953,10 @@ int Kwave::TopWidget::newWindow(Kwave::FileContext *&context, const QUrl &url)
 
 	    if (context && context->isEmpty()) {
 		// current context is empty, no main widget etc -> discard it
-		if (m_context_map.contains(0)) {
+                if (m_context_map.contains(Q_NULLPTR)) {
 		    // must have been the default context
-		    Q_ASSERT(m_context_map[0] == context);
-		    m_context_map.remove(0);
+                    Q_ASSERT(m_context_map[Q_NULLPTR] == context);
+                    m_context_map.remove(Q_NULLPTR);
 		}
 
 		// NOTE: do not handle the following context switch
@@ -1320,7 +1317,7 @@ void Kwave::TopWidget::updateMenu()
 {
     const Kwave::FileContext *context = currentContext();
     Kwave::SignalManager *signal_manager =
-	(context) ? context->signalManager() : 0;
+	(context) ? context->signalManager() : Q_NULLPTR;
     Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
@@ -1364,9 +1361,9 @@ void Kwave::TopWidget::updateMenu()
 	// update the "Windows" menu
 	m_menu_manager->clearNumberedMenu(_("ID_WINDOW_LIST"));
 	unsigned int win_count = 0;
-	foreach (const Kwave::FileContext *context, m_context_map.values()) {
-	    if (!context) continue;
-	    QString caption = context->windowCaption(false);
+	foreach (const Kwave::FileContext *ctx, m_context_map.values()) {
+	    if (!ctx) continue;
+	    QString caption = ctx->windowCaption(false);
 	    if (!caption.length()) continue;
 	    m_menu_manager->addNumberedMenuEntry(_("ID_WINDOW_LIST"),
 	        caption, QString());
@@ -1589,7 +1586,7 @@ void Kwave::TopWidget::subWindowDeleted(QObject *obj)
 
     if (m_context_map.isEmpty()) {
 	// keep the default context, without a window
-	m_context_map[0] = context;
+        m_context_map[Q_NULLPTR] = context;
     } else {
 	// remove the context
 	context->release();
@@ -1618,7 +1615,7 @@ void Kwave::TopWidget::dropEvent(QDropEvent *event)
 	bool first = true;
 	foreach (const QUrl &url, event->mimeData()->urls()) {
 	    QString filename = url.toLocalFile();
-	    QString mimetype = Kwave::CodecManager::whatContains(url);
+            QString mimetype = Kwave::CodecManager::mimeTypeOf(url);
 	    if (Kwave::CodecManager::canDecode(mimetype)) {
 		if (first) {
 		    // first dropped URL -> open in this window
