@@ -44,28 +44,28 @@ namespace Kwave
 	explicit UndoModifyMetaDataAction(const Kwave::MetaDataList &meta_data);
 
 	/** Destructor */
-	virtual ~UndoModifyMetaDataAction();
+        virtual ~UndoModifyMetaDataAction() Q_DECL_OVERRIDE;
 
 	/**
 	* Returns a verbose short description of the action.
 	*/
-	QString description() Q_DECL_OVERRIDE;
+        virtual QString description() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undoSize() */
-	qint64 undoSize() Q_DECL_OVERRIDE;
+        virtual qint64 undoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::redoSize() */
-	qint64 redoSize() Q_DECL_OVERRIDE;
+        virtual qint64 redoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::store() */
-	bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undo() */
-	Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
 	                                bool with_redo) Q_DECL_OVERRIDE;
 
 	/** dump, for debugging purposes */
-	void dump(const QString &indent) Q_DECL_OVERRIDE;
+        virtual void dump(const QString &indent) Q_DECL_OVERRIDE;
 
     protected:
 
