@@ -43,13 +43,13 @@ namespace Kwave
 	BandPass();
 
 	/** Destructor */
-	virtual ~BandPass();
+        virtual ~BandPass() Q_DECL_OVERRIDE;
 
 	/** does the calculation */
-	void goOn() Q_DECL_OVERRIDE;
+        virtual void goOn() Q_DECL_OVERRIDE;
 
 	/** @see TransmissionFunction::at() */
-	double at(double f) Q_DECL_OVERRIDE;
+        virtual double at(double f) Q_DECL_OVERRIDE;
 
     signals:
 
