@@ -23,7 +23,6 @@
 #include <QApplication>
 #include <QByteArray>
 #include <QList>
-#include <QMimeType>
 #include <QVarLengthArray>
 
 #include <KLocalizedString>
@@ -46,7 +45,7 @@
 /***************************************************************************/
 Kwave::FlacEncoder::FlacEncoder()
     :Kwave::Encoder(), FLAC::Encoder::Stream(),
-     m_vorbis_comment_map(), m_dst(0)
+     m_vorbis_comment_map(), m_dst(Q_NULLPTR)
 {
     REGISTER_MIME_TYPES
     REGISTER_COMPRESSION_TYPES
@@ -95,7 +94,7 @@ void Kwave::FlacEncoder::metadata_callback(const ::FLAC__StreamMetadata *)
 
 /***************************************************************************/
 Kwave::FlacEncoder::VorbisCommentContainer::VorbisCommentContainer()
-    :m_vc(0)
+    :m_vc(Q_NULLPTR)
 {
     m_vc = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT);
     Q_ASSERT(m_vc);
@@ -322,7 +321,7 @@ bool Kwave::FlacEncoder::encode(QWidget *widget,
 	flac_metadata.remove(0);
     }
 
-    m_dst  = 0;
+    m_dst = Q_NULLPTR;
     dst.close();
 
     while (!flac_buffer.isEmpty()) {
