@@ -94,12 +94,23 @@
 
 /***************************************************************************/
 Kwave::OpusEncoder::OpusEncoder()
-    :m_comments_map(), m_info(),
-     m_downmix(DOWNMIX_AUTO), m_bitrate(0),
-     m_coding_rate(0), m_encoder_channels(0), m_channel_mixer(0),
-     m_rate_converter(0), m_frame_size(0), m_extra_out(0), m_opus_header(),
-     m_max_frame_bytes(0), m_packet_buffer(0), m_encoder(0),
-     m_encoder_input(0), m_last_queue_element(0), m_buffer(0)
+    :m_comments_map(),
+     m_info(),
+     m_downmix(DOWNMIX_AUTO),
+     m_bitrate(0),
+     m_coding_rate(0),
+     m_encoder_channels(0),
+     m_channel_mixer(Q_NULLPTR),
+     m_rate_converter(Q_NULLPTR),
+     m_frame_size(0),
+     m_extra_out(0),
+     m_opus_header(),
+     m_max_frame_bytes(0),
+     m_packet_buffer(Q_NULLPTR),
+     m_encoder(Q_NULLPTR),
+     m_encoder_input(Q_NULLPTR),
+     m_last_queue_element(Q_NULLPTR),
+     m_buffer(Q_NULLPTR)
 {
 
     memset(&m_opus_header, 0x00, sizeof(m_opus_header));
@@ -407,7 +418,7 @@ bool Kwave::OpusEncoder::setupEncoder(QWidget *widget, unsigned int tracks,
     if (force_narrow) {
 	for (unsigned int i = 0; i < m_opus_header.streams; i++ ) {
 	    if (force_narrow & (1 << i)) {
-		::OpusEncoder *oe = 0;
+                ::OpusEncoder *oe = Q_NULLPTR;
 
 		opus_multistream_encoder_ctl(
 		    m_encoder,
@@ -440,8 +451,8 @@ bool Kwave::OpusEncoder::setupEncoder(QWidget *widget, unsigned int tracks,
 /***************************************************************************/
 bool Kwave::OpusEncoder::setupBitrateMode(QWidget *widget)
 {
+    const bool with_cvbr = false;
     int err;
-    bool with_cvbr = false;
 
     // determine a reasonable bitrate in case we still use "autodetect"
     if (m_bitrate < 0) {
@@ -963,26 +974,26 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
 void Kwave::OpusEncoder::close()
 {
     if (m_channel_mixer) delete m_channel_mixer;
-    m_channel_mixer = 0;
+    m_channel_mixer = Q_NULLPTR;
 
     if (m_rate_converter) delete m_rate_converter;
-    m_rate_converter = 0;
+    m_rate_converter = Q_NULLPTR;
 
     if (m_buffer) delete m_buffer;
-    m_buffer = 0;
+    m_buffer = Q_NULLPTR;
 
     if (m_encoder) opus_multistream_encoder_destroy(m_encoder);
-    m_encoder = 0;
+    m_encoder = Q_NULLPTR;
 
     ogg_stream_clear(&m_os);
 
     if (m_packet_buffer) free(m_packet_buffer);
-    m_packet_buffer = 0;
+    m_packet_buffer = Q_NULLPTR;
 
     if (m_encoder_input) free(m_encoder_input);
-    m_encoder_input = 0;
+    m_encoder_input = Q_NULLPTR;
 
-    m_last_queue_element = 0;
+    m_last_queue_element = Q_NULLPTR;
 }
 
 /***************************************************************************/
