@@ -37,7 +37,6 @@
 #include <QLocale>
 #include <QSpinBox>
 #include <QDateEdit>
-#include <QMimeType>
 
 #include <KComboBox>
 #include <KConfig>
@@ -152,7 +151,7 @@ void Kwave::FileInfoDialog::setupFileInfoTab()
      * the old file name
      */
     if (file_name.length()) {
-	QString mt = Kwave::CodecManager::whatContains(QUrl(file_name));
+        QString mt = Kwave::CodecManager::mimeTypeOf(QUrl(file_name));
 	Kwave::Encoder *encoder = Kwave::CodecManager::encoder(mt);
 	if (encoder) {
 	    // encoder does not support the file's mime type -> switch
@@ -501,7 +500,7 @@ void Kwave::FileInfoDialog::setupSourceTab()
 	QVariant(m_info.get(Kwave::INF_CD)).toInt() : 0;
     sbCD->setValue(cd);
 
-    initInfo(0, sbCDs, Kwave::INF_CDS);
+    initInfo(Q_NULLPTR, sbCDs, Kwave::INF_CDS);
     int cds = (m_info.contains(Kwave::INF_CDS)) ?
 	QVariant(m_info.get(Kwave::INF_CDS)).toInt() : 0;
     sbCDs->setValue(cds);
@@ -511,7 +510,7 @@ void Kwave::FileInfoDialog::setupSourceTab()
 	QVariant(m_info.get(Kwave::INF_TRACK)).toInt() : 0;
     sbTrack->setValue(track);
 
-    initInfo(0, sbTracks, Kwave::INF_TRACKS);
+    initInfo(Q_NULLPTR, sbTracks, Kwave::INF_TRACKS);
     int tracks = (m_info.contains(Kwave::INF_TRACKS)) ?
 	QVariant(m_info.get(Kwave::INF_TRACKS)).toInt() : 0;
     sbTracks->setValue(tracks);
