@@ -56,10 +56,6 @@
 #include "RecordParams.h"
 #include "RecordState.h"
 
-#include "krec_record.xpm"
-#include "record_pause.xpm"
-#include "record_stop.xpm"
-
 // status bar icons
 #include "ledgreen.xpm"
 #include "ledlightgreen.xpm"
@@ -100,13 +96,13 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
      m_supported_resolutions(), m_buffer_progress_count(0),
      m_buffer_progress_total(0), m_buffer_progress_timer(this),
      m_record_enabled(true), m_samples_recorded(0),
-     m_enable_setDevice(true), m_state_icon_widget(0)
+     m_enable_setDevice(true), m_state_icon_widget(Q_NULLPTR)
 {
-    m_status_bar.m_state           = 0;
-    m_status_bar.m_time            = 0;
-    m_status_bar.m_sample_rate     = 0;
-    m_status_bar.m_bits_per_sample = 0;
-    m_status_bar.m_tracks          = 0;
+    m_status_bar.m_state           = Q_NULLPTR;
+    m_status_bar.m_time            = Q_NULLPTR;
+    m_status_bar.m_sample_rate     = Q_NULLPTR;
+    m_status_bar.m_bits_per_sample = Q_NULLPTR;
+    m_status_bar.m_tracks          = Q_NULLPTR;
 
     setupUi(this);
 
@@ -114,12 +110,10 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     m_params.fromList(params);
 
     /* set the icons of the record control buttons */
-    KIconLoader icon_loader;
-    btNew->setIcon(   QIcon(icon_loader.loadIcon(_("document-new"),
-	              KIconLoader::Toolbar)));
-    btStop->setIcon(  QIcon(QPixmap(xpm_stop)));
-    btPause->setIcon( QIcon(QPixmap(xpm_pause)));
-    btRecord->setIcon(QIcon(QPixmap(xpm_krec_record)));
+    btNew->setIcon(   QIcon::fromTheme(_("document-new")));
+    btStop->setIcon(  QIcon::fromTheme(_("kwave_player_stop")));
+    btPause->setIcon( QIcon::fromTheme(_("kwave_player_pause")));
+    btRecord->setIcon(QIcon::fromTheme(_("kwave_player_record")));
 
     // fill the combo box with playback methods
     unsigned int index=0;
@@ -382,7 +376,7 @@ void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
     // device controls...
     m_enable_setDevice = false;
 
-    KIconLoader icon_loader;
+    KIconLoader *icon_loader = KIconLoader::global();
 
     cbDevice->clearEditText();
     cbDevice->clear();
@@ -414,11 +408,11 @@ void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
 
 	// build a tree with all nodes in the list
 	foreach (QString dev_id, devices) {
-	    QTreeWidgetItem *parent = 0;
+            QTreeWidgetItem *parent = Q_NULLPTR;
 
 	    QStringList list = dev_id.split(_("||"), QString::KeepEmptyParts);
 	    foreach (QString token, list) {
-		QTreeWidgetItem *item = 0;
+                QTreeWidgetItem *item = Q_NULLPTR;
 
 		// split the icon name from the token
 		QString icon_name;
@@ -474,8 +468,8 @@ void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
 		    }
 		}
 
-		if (item && icon_name.length()) {
-		    QIcon icon = icon_loader.loadIcon(
+		if (item && icon_name.length() && icon_loader) {
+		    QIcon icon = icon_loader->loadIcon(
 			icon_name, KIconLoader::User);
 		    item->setIcon(0, icon);
 		}
@@ -552,7 +546,7 @@ void Kwave::RecordDialog::setDevice(const QString &device)
 
     if (listDevices->isEnabled()) {
 	// treeview mode
-	QTreeWidgetItem *node = m_devices_list_map.key(device, 0);
+        QTreeWidgetItem *node = m_devices_list_map.key(device, Q_NULLPTR);
 	if (node) {
 	    node->setSelected(true);
 	    listDevices->scrollToItem(node);
