@@ -62,12 +62,12 @@ KWAVE_PLUGIN(sonagram, SonagramPlugin)
 Kwave::SonagramPlugin::SonagramPlugin(QObject *parent,
                                       const QVariantList &args)
     :Kwave::Plugin(parent, args),
-     m_sonagram_window(0),
-     m_selection(0),
+     m_sonagram_window(Q_NULLPTR),
+     m_selection(Q_NULLPTR),
      m_slices(0), m_fft_points(0),
      m_window_type(Kwave::WINDOW_FUNC_NONE), m_color(true),
      m_track_changes(true), m_follow_selection(false), m_image(),
-     m_overview_cache(0), m_slice_pool(), m_valid(MAX_SLICES, false),
+     m_overview_cache(Q_NULLPTR), m_slice_pool(), m_valid(MAX_SLICES, false),
      m_pending_jobs(), m_lock_job_list(QMutex::Recursive), m_future(),
      m_repaint_timer()
 {
@@ -89,23 +89,23 @@ Kwave::SonagramPlugin::~SonagramPlugin()
     m_repaint_timer.stop();
 
     if (m_sonagram_window) delete m_sonagram_window;
-    m_sonagram_window = 0;
+    m_sonagram_window = Q_NULLPTR;
 
     if (m_selection) delete m_selection;
-    m_selection = 0;
+    m_selection = Q_NULLPTR;
 }
 
 //***************************************************************************
 QStringList *Kwave::SonagramPlugin::setup(QStringList &previous_params)
 {
-    QStringList *result = 0;
+    QStringList *result = Q_NULLPTR;
 
     // try to interprete the list of previous parameters, ignore errors
     if (previous_params.count()) interpreteParameters(previous_params);
 
     Kwave::SonagramDialog *dlg = new(std::nothrow) Kwave::SonagramDialog(*this);
     Q_ASSERT(dlg);
-    if (!dlg) return 0;
+    if (!dlg) return Q_NULLPTR;
 
     dlg->setWindowFunction(m_window_type);
     dlg->setColorMode(m_color ? 1 : 0);
@@ -160,11 +160,11 @@ int Kwave::SonagramPlugin::start(QStringList &params)
 {
     // clean up leftovers from last run
     if (m_sonagram_window) delete m_sonagram_window;
-    m_sonagram_window = 0;
+    m_sonagram_window = Q_NULLPTR;
     if (m_selection)       delete m_selection;
-    m_selection = 0;
+    m_selection = Q_NULLPTR;
     if (m_overview_cache)  delete m_overview_cache;
-    m_overview_cache = 0;
+    m_overview_cache = Q_NULLPTR;
 
     Kwave::SignalManager &sig_mgr = signalManager();
 
@@ -186,7 +186,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     QList<unsigned int> selected_channels;
     sample_index_t offset = 0;
     sample_index_t length = 0;
-    length = selection(&selected_channels, &offset, 0, true);
+    length = selection(&selected_channels, &offset, Q_NULLPTR, true);
 
     // abort if nothing is selected
     if (!length || selected_channels.isEmpty())
@@ -239,7 +239,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     } else {
 	// overview cache is no longer needed
 	delete m_overview_cache;
-	m_overview_cache = 0;
+        m_overview_cache = Q_NULLPTR;
     }
 
     // connect all needed signals
@@ -607,13 +607,13 @@ void Kwave::SonagramPlugin::windowDestroyed()
 {
     cancel();
 
-    m_sonagram_window = 0; // closes itself !
+    m_sonagram_window = Q_NULLPTR; // closes itself !
 
     if (m_selection) delete m_selection;
-    m_selection = 0;
+    m_selection = Q_NULLPTR;
 
     if (m_overview_cache) delete m_overview_cache;
-    m_overview_cache = 0;
+    m_overview_cache = Q_NULLPTR;
 
     release();
 }
